==> dl.php?src=linea21_2_5_0.zip: linea21/languages/fr/lang_resources.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	nommage des modules
 *  	*/
$lang['resources']['name']='ressource';
$lang['resources']['confirm_add'] = "Ajout de la ressource réalisé avec succès\n";
$lang['resources']['confirm_mod'] = "Modification de la ressource réalisée avec succès\n";
$lang['resources']['confirm_sup'] ="Suppression de la ressource réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['resources']['add']= 'Ajout d\'une '.$lang['resources']['name'];
$lang['resources']['mod']= 'Modification d\'une '.$lang['resources']['name'];
$lang['resources']['sup']= 'Suppression d\'une '.$lang['resources']['name'];
$lang['resources']['det']= 'Détails d\'une '.$lang['resources']['name'];
$lang['resources']['list']= 'Consultation des ressources';
$lang['resources']['go_back']='Retour ';

/*	nommage des 'parents'
 *  	*/
$lang['resources']['publication_type']='à la publication';
$lang['resources']['workshop_type']='au compte-rendu';

/*	nommage rubrique add / mod /det
 *  	*/
$lang['resources']['add_title']='Saisie des informations de la nouvelle '.$lang['resources']['name'];
$lang['resources']['mod_title']='Modification des informations de la '.$lang['resources']['name'];


/*	nommage élément rubrique
 *  	*/
$lang['resources']['supp_info']='Vous avez choisi de supprimer la ressource de type ';
$lang['resources']['next']='suivante :';
$lang['resources']['link_res']='lien';
$lang['resources']['biblio_res']='bibliographique';
$lang['resources']['multi_res']='ressources';

$lang['resources']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['resources']['url_mask']='masque textuel';
$lang['resources']['url_visual_test']='rendu visuel';

$lang['resources']['biblio_author']='auteur';
$lang['resources']['biblio_title']='titre de l\'ouvrage';
$lang['resources']['biblio_sub_title']='sous-titre';
$lang['resources']['biblio_editor']='éditeur';
$lang['resources']['biblio_published_date']='date de publication';

$lang['resources']['multi_name']='nom';
$lang['resources']['multi_description']='description';

/*	check integrité des données
 *  	*/
$lang['resources']['no_url']='Vous devez impérativement fournir une '.$lang['resources']['url'];
$lang['resources']['invalid_protocol']='Le protocole indiqué n\'est pas reconnu par l\'application. Veuillez vérifier votre syntaxe.';
$lang['resources']['invalid_link']='Vous devez entrer un lien valide sous la forme : \'http://\'.';
$lang['resources']['server_noresponse']='L\' '.$lang['resources']['url'].' semble incorrecte (le fichier ne répond pas). Veuillez vérifier sa syntaxe';

$lang['resources']['biblio_no_author']='Vous devez impérativement mentionner un auteur de l\'oeuvre';
$lang['resources']['biblio_no_title']='Vous devez impérativement mentionner le titre de l\'oeuvre';

$lang['resources']['multi_no_name']='Vous devez impérativement fournir un nom au nouveau document';
$lang['resources']['multi_no_description']='Vous devez impérativement fournir une description du nouveau document';


/*	nommage quickbox
 *  	*/
$lang['resources']['qb_titleadd']=' derniers ajouts effectués';
$lang['resources']['qb_titlemod']=' dernières modifications effectuées';
$lang['resources']['qb_titlesup']=' dernières suppressions effectuées';
$lang['resources']['qb_titlepubli']=' dernières publications effectuées';
$lang['resources']['qb_title_type_W']=' sur le compte rendu';
$lang['resources']['qb_title_type_P']=' sur la publication';


/*	divers
 *  	*/
$lang['resources']['no_link']="Aucun site n'est actuellement associé";
$lang['resources']['del_link']="Supprimer le lien";
$lang['resources']['mod_link']="Modifier le lien";

$lang['resources']['no_multi']="Aucun document n'est actuellement associé";
$lang['resources']['del_multi']="Supprimer le document numérique";
$lang['resources']['mod_multi']="Modifier le document numérique";

$lang['resources']['no_biblio']="Aucune référence bibliographique n'est actuellement associée";
$lang['resources']['del_biblio']="Supprimer la référence bibliographique";
$lang['resources']['mod_biblio']="Modifier la référence bibliographique";

$lang['resources']['no_part']="Aucune partie n'est actuellement associée";
$lang['resources']['del_part']="Supprimer la partie";
$lang['resources']['mod_part']="Modifier la partie";


/*	rubrique d'aide
 *  	*/
$lang['resources']['help_add1']='Pour ajouter une ressource, vous devez saisir  les informations requises dans le formulaire ci-dessus.';
$lang['resources']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['resources']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour les modifier';

$lang['resources']['help_list1']='Pour afficher le détail d\'une publication, cliquez sur le titre de celui-ci';
$lang['resources']['help_list2']='Vous pouvez supprimer une publication en cliquant sur l\'icône de suppression qui lui est associée';
$lang['resources']['help_list3']='Vous pouvez modifier une publication en cliquant sur l\'icône de modification qui lui est associée';
$lang['resources']['help_list4']='Vous pouvez utiliser les filtres \'par statut\' pour afficher les publications desirées';
$lang['resources']['help_list5']='Pour ajouter une publication, cliquez sur le lien \'ajouter une publication\' dans la barre de titre';


$lang['resources']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['resources']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les paramètres dans le récapitulatif';
$lang['resources']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier de nouveau les données';

$lang['resources']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de la ressource courante, cliquer sur \'Annuler\'.';


?>

==> dl.php?src=linea21_2_7_0.zip: linea21/languages/fr/lang_resources.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	nommage des modules
 *  	*/
$lang['resources']['name']='ressource';
$lang['resources']['confirm_add'] = "Ajout de la ressource réalisé avec succès\n";
$lang['resources']['confirm_mod'] = "Modification de la ressource réalisée avec succès\n";
$lang['resources']['confirm_sup'] ="Suppression de la ressource réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['resources']['add']= 'Ajout d\'une '.$lang['resources']['name'];
$lang['resources']['mod']= 'Modification d\'une '.$lang['resources']['name'];
$lang['resources']['sup']= 'Suppression d\'une '.$lang['resources']['name'];
$lang['resources']['det']= 'Détails d\'une '.$lang['resources']['name'];
$lang['resources']['list']= 'Consultation des ressources';
$lang['resources']['go_back']='Retour ';

/*	nommage des 'parents'
 *  	*/
$lang['resources']['publication_type']='à la publication';
$lang['resources']['workshop_type']='au compte-rendu';

/*	nommage rubrique add / mod /det
 *  	*/
$lang['resources']['add_title']='Saisie des informations de la nouvelle '.$lang['resources']['name'];
$lang['resources']['mod_title']='Modification des informations de la '.$lang['resources']['name'];


/*	nommage élément rubrique
 *  	*/
$lang['resources']['supp_info']='Vous avez choisi de supprimer la ressource de type ';
$lang['resources']['next']='suivante :';
$lang['resources']['link_res']='lien';
$lang['resources']['biblio_res']='bibliographique';
$lang['resources']['multi_res']='ressources';

$lang['resources']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['resources']['url_mask']='masque textuel';
$lang['resources']['url_visual_test']='rendu visuel';

$lang['resources']['biblio_author']='auteur';
$lang['resources']['biblio_title']='titre de l\'ouvrage';
$lang['resources']['biblio_sub_title']='sous-titre';
$lang['resources']['biblio_editor']='éditeur';
$lang['resources']['biblio_published_date']='date de publication';

$lang['resources']['multi_name']='nom';
$lang['resources']['multi_description']='description';

/*	check integrité des données
 *  	*/
$lang['resources']['no_url']='Vous devez impérativement fournir une '.$lang['resources']['url'];
$lang['resources']['invalid_protocol']='Le protocole indiqué n\'est pas reconnu par l\'application. Veuillez vérifier votre syntaxe.';
$lang['resources']['invalid_link']='Vous devez entrer un lien valide sous la forme : \'http(s)://\'.';
$lang['resources']['server_noresponse']='L\' '.$lang['resources']['url'].' semble incorrecte (le fichier ne répond pas). Veuillez vérifier sa syntaxe';

$lang['resources']['biblio_no_author']='Vous devez impérativement mentionner un auteur de l\'oeuvre';
$lang['resources']['biblio_no_title']='Vous devez impérativement mentionner le titre de l\'oeuvre';

$lang['resources']['multi_no_name']='Vous devez impérativement fournir un nom au nouveau document';
$lang['resources']['multi_no_description']='Vous devez impérativement fournir une description du nouveau document';


/*	nommage quickbox
 *  	*/
$lang['resources']['qb_titleadd']=' derniers ajouts effectués';
$lang['resources']['qb_titlemod']=' dernières modifications effectuées';
$lang['resources']['qb_titlesup']=' dernières suppressions effectuées';
$lang['resources']['qb_titlepubli']=' dernières publications effectuées';
$lang['resources']['qb_title_type_W']=' sur le compte rendu';
$lang['resources']['qb_title_type_P']=' sur la publication';


/*	divers
 *  	*/
$lang['resources']['no_link']="Aucun site n'est actuellement associé";
$lang['resources']['del_link']="Supprimer le lien";
$lang['resources']['mod_link']="Modifier le lien";

$lang['resources']['no_multi']="Aucun document n'est actuellement associé";
$lang['resources']['del_multi']="Supprimer le document numérique";
$lang['resources']['mod_multi']="Modifier le document numérique";

$lang['resources']['no_biblio']="Aucune référence bibliographique n'est actuellement associée";
$lang['resources']['del_biblio']="Supprimer la référence bibliographique";
$lang['resources']['mod_biblio']="Modifier la référence bibliographique";

$lang['resources']['no_part']="Aucune partie n'est actuellement associée";
$lang['resources']['del_part']="Supprimer la partie";
$lang['resources']['mod_part']="Modifier la partie";


/*	rubrique d'aide
 *  	*/
$lang['resources']['help_add1']='Pour ajouter une ressource, vous devez saisir  les informations requises dans le formulaire ci-dessus.';
$lang['resources']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['resources']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour les modifier';

$lang['resources']['help_list1']='Pour afficher le détail d\'une publication, cliquez sur le titre de celui-ci';
$lang['resources']['help_list2']='Vous pouvez supprimer une publication en cliquant sur l\'icône de suppression qui lui est associée';
$lang['resources']['help_list3']='Vous pouvez modifier une publication en cliquant sur l\'icône de modification qui lui est associée';
$lang['resources']['help_list4']='Vous pouvez utiliser les filtres \'par statut\' pour afficher les publications desirées';
$lang['resources']['help_list5']='Pour ajouter une publication, cliquez sur le lien \'ajouter une publication\' dans la barre de titre';


$lang['resources']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['resources']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les paramètres dans le récapitulatif';
$lang['resources']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier de nouveau les données';

$lang['resources']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de la ressource courante, cliquer sur \'Annuler\'.';


?>
